@@ -1,13 +1,6 @@
-#!/usr/bin/env python3
-# --------------------------------------------------------------------------------------
 # SPDX-FileCopyrightText: 2021 Magenta ApS <https://magenta.dk>
 # SPDX-License-Identifier: MPL-2.0
-# --------------------------------------------------------------------------------------
-# --------------------------------------------------------------------------------------
-# Imports
-# --------------------------------------------------------------------------------------
 from typing import Literal
-from typing import Optional
 
 from pydantic import Field
 
@@ -26,7 +19,7 @@ class Detail(UUIDBase):
 
 class DetailTermination(Detail):
 
-    validity: Optional[dict] = Field(
+    validity: dict | None = Field(
         description="MO unit validity, determining in what date-interval "
         "a unit is available."
     )
